## ----setup, include=FALSE, cache=FALSE, show=FALSE--------------------------------------
library(knitr)
# set global chunk options
opts_chunk$set(fig.path='fig/PSSeg-', fig.align='center', fig.show='hold')
options(replace.assign=TRUE,width=90)

## ----include=FALSE----------------------------------------------------------------------
opts_chunk$set(dev='png', fig.width=5, fig.height=5)

## ----message=FALSE----------------------------------------------------------------------
library("jointseg")

## ----data-------------------------------------------------------------------------------
data <- loadCnRegionData(dataSet="GSE29172", tumorFraction=1)
str(data)

## ---------------------------------------------------------------------------------------
table(data[["region"]])

## ----regDat, echo=TRUE------------------------------------------------------------------
idxs <- sort(sample(1:nrow(data), 2e4))
plotSeg(data[idxs, ])

## ----createProfile----------------------------------------------------------------------
K <- 10
bkp <- c(408,1632,3905, 5890,6709, 10481, 12647,14089,17345,18657)
len <- 2e4
sim <- getCopyNumberDataByResampling(len, bkp=bkp, minLength=500, regData=data)
datS <- sim$profile
str(datS)

## ----profile-fig------------------------------------------------------------------------
plotSeg(datS, sim$bkp)

## ----log-transform----------------------------------------------------------------------
datS$c <- log2(datS$c)-1

## ----BinSeg-----------------------------------------------------------------------------
resRBS <- PSSeg(data=datS, K=2*K, method="RBS", stat=c("c", "d"), profile=TRUE)

## ---------------------------------------------------------------------------------------
resRBS$prof[, "time"]

## ----plotRBS----------------------------------------------------------------------------
plotSeg(datS, list(true=sim$bkp, est=resRBS$bestBkp))

## ---------------------------------------------------------------------------------------
print(getTpFp(resRBS$bestBkp, sim$bkp, tol=5))

## ---------------------------------------------------------------------------------------
perf <- sapply(0:10, FUN=function(tol) {
    getTpFp(resRBS$bestBkp, sim$bkp, tol=tol,relax = -1)
})
print(perf)

## ----sessionInfo------------------------------------------------------------------------
sessionInfo()

## ----message=FALSE----------------------------------------------------------------------
citation("jointseg")

