## ----setup, include=FALSE, cache=FALSE, show=FALSE--------------------------------------
library(knitr)
# set global chunk options
opts_chunk$set(fig.path='fig/datGen-', fig.align='center', fig.show='hold')
options(replace.assign=TRUE,width=90)

## ----include=FALSE----------------------------------------------------------------------
opts_chunk$set(dev='png', fig.width=5, fig.height=5)

## ----message=FALSE----------------------------------------------------------------------
library(jointseg)

## ----truth------------------------------------------------------------------------------
n <- 1e4                                 ## signal length
bkp <- c(2334, 6121)                     ## breakpoint positions
regions <- c("(1,1)", "(1,2)", "(0,2)")  ## copy number regions

## ----settings---------------------------------------------------------------------------
ylims <- cbind(c(0, 5), c(-0.1, 1.1))
colG <- rep("#88888855", n)
hetCol <- "#00000088"

## ----plottingFunction-------------------------------------------------------------------
plotFUN <- function(dataSet, tumorFraction) {
    regDat <- loadCnRegionData(dataSet=dataSet, tumorFraction=tumorFraction) 
    sim <- getCopyNumberDataByResampling(n, bkp=bkp, regions=regions, regData=regDat)
    dat <- sim$profile
    wHet <- which(dat$genotype==1/2)
    colGG <- colG
    colGG[wHet] <- hetCol
    plotSeg(dat, sim$bkp, ylims=ylims, col=colGG)
}

## ---------------------------------------------------------------------------------------
ds <- "GSE29172"

## ----label=Affy100----------------------------------------------------------------------
tf <- 1
plotFUN(ds, tf)

## ----label=Affy100b---------------------------------------------------------------------
tf <- 1
plotFUN(ds, tf)

## ----label=Affy70-----------------------------------------------------------------------
tf <- .7
plotFUN(ds, tf)

## ----label=Affy50-----------------------------------------------------------------------
tf <- .5
plotFUN(ds, tf)

## ---------------------------------------------------------------------------------------
ds <- "GSE11976"

## ----label=Illu100----------------------------------------------------------------------
tf <- 1
plotFUN(ds, tf)

## ----label=Illu100b---------------------------------------------------------------------
tf <- 1
plotFUN(ds, tf)

## ----label=Illu79-----------------------------------------------------------------------
tf <- .79
plotFUN(ds, tf)

## ----label=Illu50-----------------------------------------------------------------------
tf <- .5
plotFUN(ds, tf)

## ---------------------------------------------------------------------------------------
sessionInfo()

## ----message=FALSE----------------------------------------------------------------------
citation("jointseg")

